==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorTokenHardwareAllOfVerify.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenHardwareAllOfVerify
 */
@JsonPropertyOrder({ UserFactorTokenHardwareAllOfVerify.JSON_PROPERTY_PASS_CODE })
@JsonTypeName("UserFactorTokenHardware_allOf_verify")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorTokenHardwareAllOfVerify implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PASS_CODE = "passCode";
    private String passCode;

    public UserFactorTokenHardwareAllOfVerify() {
    }

    public UserFactorTokenHardwareAllOfVerify passCode(String passCode) {

        this.passCode = passCode;
        return this;
    }

    /**
     * OTP for the current time window
     *
     * @return passCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "cccccceukngdfgkukfctkcvfidnetljjiknckkcjulji", value = "OTP for the current time window")
    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPassCode() {
        return passCode;
    }

    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenHardwareAllOfVerify userFactorTokenHardwareAllOfVerify = (UserFactorTokenHardwareAllOfVerify) o;
        return Objects.equals(this.passCode, userFactorTokenHardwareAllOfVerify.passCode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(passCode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenHardwareAllOfVerify {\n");
        sb.append("    passCode: ").append(toIndentedString(passCode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorTokenHardwareAllOfVerify.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenHardwareAllOfVerify
 */
@JsonPropertyOrder({ UserFactorTokenHardwareAllOfVerify.JSON_PROPERTY_PASS_CODE })
@JsonTypeName("UserFactorTokenHardware_allOf_verify")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserFactorTokenHardwareAllOfVerify implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PASS_CODE = "passCode";
    private String passCode;

    public UserFactorTokenHardwareAllOfVerify() {
    }

    public UserFactorTokenHardwareAllOfVerify passCode(String passCode) {

        this.passCode = passCode;
        return this;
    }

    /**
     * OTP for the current time window
     *
     * @return passCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "cccccceukngdfgkukfctkcvfidnetljjiknckkcjulji", value = "OTP for the current time window")
    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPassCode() {
        return passCode;
    }

    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenHardwareAllOfVerify userFactorTokenHardwareAllOfVerify = (UserFactorTokenHardwareAllOfVerify) o;
        return Objects.equals(this.passCode, userFactorTokenHardwareAllOfVerify.passCode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(passCode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenHardwareAllOfVerify {\n");
        sb.append("    passCode: ").append(toIndentedString(passCode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
